package com.tecnavia.webanalytics

import android.annotation.SuppressLint
import android.content.Context
import android.webkit.WebChromeClient
import android.webkit.WebView
import android.webkit.WebViewClient
import com.facebook.react.bridge.Arguments
import com.facebook.react.bridge.Promise
import com.facebook.react.bridge.ReactApplicationContext
import com.facebook.react.bridge.ReactContextBaseJavaModule
import com.facebook.react.bridge.ReactMethod
import com.facebook.react.bridge.ReadableMap
import org.json.JSONObject

class WebAnalyticsModule (context: ReactApplicationContext) : ReactContextBaseJavaModule(context) {
    private var wb: WebView? = null;
    private var _debugMode: Boolean = false;
    private var _userId: String? = null;

    override fun getName(): String {
        return "WebAnalytics"
    }

    @ReactMethod
    fun debugMode(enabled: Boolean){
        _debugMode = enabled
        currentActivity?.runOnUiThread{
            WebView.setWebContentsDebuggingEnabled(enabled)
        }
    }

    @ReactMethod
    fun logEvent(name: String, data: ReadableMap, promise: Promise){
        try {
            logEventToWb(name, Utils.convertMapToJson(data))
            promise.resolve(Arguments.createMap())
        }catch (e: Exception) {
            promise.reject(e)
        }
    }

    @ReactMethod
    fun logPageView(data: ReadableMap, promise: Promise){
        try {
            logPageViewToWb(Utils.convertMapToJson(data))
            promise.resolve(Arguments.createMap())
        }catch (e: Exception) {
            promise.reject(e)
        }
    }

    @ReactMethod
    fun logScreenView(data: ReadableMap, promise: Promise){
        try {
            logScreenViewToWb(Utils.convertMapToJson(data))
            promise.resolve(Arguments.createMap())
        }catch (e: Exception) {
            promise.reject(e)
        }
    }

    @ReactMethod
    fun setUserId(userId: String?, promise: Promise){
        try{
            _userId = userId
            promise.resolve(Arguments.createMap())
        }catch (e: Exception) {
            promise.reject(e)
        }
    }

    @ReactMethod
    fun addInstance(config: ReadableMap, promise: Promise){
        val name = config.getString("name");
        addInstanceToWb(name, Utils.convertMapToJson(config))
        promise.resolve(Arguments.createMap())
    }

    @ReactMethod
    fun removeInstance(name: String, promise: Promise){
        removeInstanceFromWb(name)
        promise.resolve(Arguments.createMap())
    }

    @SuppressLint("SetJavaScriptEnabled")
    @ReactMethod
    fun initializeWebMode(html: String, promise: Promise){
        currentActivity?.runOnUiThread {
            try {
                if (currentActivity == null) {
                    promise.reject(Exception("Can't initialize WebView, missing activity context"))
                    return@runOnUiThread
                }
                val view = WebView(currentActivity as Context)
                view.settings.javaScriptEnabled = true
                view.settings.allowContentAccess = true
                view.settings.allowFileAccess = true
                view.settings.allowFileAccessFromFileURLs = true
                view.settings.allowUniversalAccessFromFileURLs = true
                view.settings.databaseEnabled = true
                view.settings.domStorageEnabled = true
                view.webViewClient = object : WebViewClient() {
                    override fun onPageFinished(view: WebView?, url: String?) {
                        super.onPageFinished(view, url)
                        promise.resolve(Arguments.createMap())
                    }
                }
                view.webChromeClient = WebChromeClient()
                view.loadDataWithBaseURL("http://localhost", html, "text/html", "UTF-8", null);
                wb = view
            } catch (e: Exception) {
                e.printStackTrace()
                promise.reject(e)
            }
        }
    }

    private fun addInstanceToWb(name: String?, config: JSONObject){
        config.put("debug_mode", _debugMode)
        if (!_userId.isNullOrEmpty()) {
            config.put("user_id", _userId)
        }
        currentActivity?.runOnUiThread{
            wb?.evaluateJavascript("addProject(\'$name\', \'$config\')", null)
        }
    }

    private fun removeInstanceFromWb(name: String?){
        currentActivity?.runOnUiThread{
            wb?.evaluateJavascript("deleteProject(\'$name\')", null)
        }
    }

    private fun logEventToWb(name: String, data: JSONObject) {
        currentActivity?.runOnUiThread{
            wb?.evaluateJavascript("logEvent(\'$name\', \'$data\')", null)
        }
    }

    private fun logPageViewToWb(data: JSONObject) {
        currentActivity?.runOnUiThread{
            wb?.evaluateJavascript("logPageView(\'$data\')", null)
        }
    }

    private fun logScreenViewToWb(data: JSONObject) {
        currentActivity?.runOnUiThread{
            wb?.evaluateJavascript("logScreenView(\'$data\')", null)
        }
    }
}