import { NativeModules } from "react-native";
import { eventNameValidator, eventParamsValidator, pageObjectValidator, screenObjectValidator } from "./utils/event-validator";
import { isString } from "./utils/validators";
import { RAW_HTML } from "./utils/scripts";
const Native = NativeModules.WebAnalytics;
export class WebAnalytics {
  debugMode(enable = false) {
    Native.debugMode(enable);
  }
  async initializeWebMode() {
    return Native.initializeWebMode(RAW_HTML);
  }
  async logEvent(name, params = {}) {
    if (eventNameValidator(name) && eventParamsValidator(params)) {
      return Native.logEvent(name, params);
    }
    return Promise.reject(new Error("something went wrong on tracking event"));
  }
  async logPageView(object) {
    if (pageObjectValidator(object)) {
      return Native.logPageView(object);
    }
    return Promise.reject(new Error("something went wrong on tracking page view"));
  }
  async logScreenView(object) {
    if (screenObjectValidator(object)) {
      return Native.logScreenView(object);
    }
    return Promise.reject(new Error("something went wrong on tracking screen view"));
  }
  async setUserId(userId) {
    return Native.setUserId(userId);
  }
  isFirebaseInstance(instance) {
    return isString(instance.projectId) && instance.projectId.length > 0;
  }
  async addInstance(instance) {
    if (!isString(instance.name) || instance.name.length === 0) {
      throw new Error("name must be a valid string");
    }
    if (this.isFirebaseInstance(instance)) {
      if (!isString(instance.appId) || instance.appId.length === 0) {
        throw new Error("appId must be a valid string");
      }
      if (!isString(instance.apiKey) || instance.apiKey.length === 0) {
        throw new Error("apiKey must be a valid string");
      }
    } else {
      if (!isString(instance.measurementId) || instance.measurementId.length === 0) {
        throw new Error("measurementId must be a valid string");
      }
    }
    return Native.addInstance(instance);
  }
  async removeInstance(name) {
    if (!isString(name) || name.length === 0) {
      throw new Error("name must be a valid string");
    }
    return Native.removeInstance(name);
  }
}
//# sourceMappingURL=analytics.js.map