const RAW_HTML = /* html */`
    <html>
        <body>
            <script type="module">
                import { initializeApp  } from 'https://www.gstatic.com/firebasejs/9.22.1/firebase-app.js';
                import { initializeAnalytics, logEvent, setAnalyticsCollectionEnabled, setUserId } from 'https://www.gstatic.com/firebasejs/9.22.1/firebase-analytics.js';

                const projects = {};

                window.addEventListener("fa_add_project", ({ detail }) => {
                    try{
                        const { name, config } = detail;
                        const { user_id, debug_mode, ...rest } = config;

                        const app = initializeApp(rest, { name })
                        projects[name] = initializeAnalytics(app, { config: { send_page_view: false } });
                        setAnalyticsCollectionEnabled(projects[name], true);
                        if (user_id !== undefined) {
                            setUserId(projects[name], user_id);
                        }
                    } catch(e){
                        console.warn(e.message);
                    }
                });

                window.addEventListener("fa_delete_project", ({ detail }) => {
                    try{
                        delete projects[detail.name];
                    } catch(e){
                        console.warn(e.message);
                    }
                });

                window.addEventListener("fa_log_event", ({ detail }) => {
                    Object.values(projects).forEach((project) => {
                        try{
                            logEvent(project, detail.name, detail.data);
                        } catch(e){
                            console.warn(e.message);
                        }
                    });
                });
            </script>
            <script>
                <!-- Google tag (gtag.js) -->
                window.dataLayer = window.dataLayer || [];
                function gtag(){
                   dataLayer.push(arguments);
                }
                gtag('js', new Date());

                const ga4Projects = {};

                window.addEventListener("ga4_add_project", ({ detail }) => {
                    try{
                        const { name, config } = detail;
                        const { measurementId, debug_mode, user_id } = config;

                        const ga4Ids = Object.values(ga4Projects);
                        //for the first TAG ID we need to create the google tag manager script
                        if (ga4Ids.length === 0) {
                            const script = document.createElement("script");
                            script.type = "text/javascript";
                            script.async = true;
                            script.src = "https://www.googletagmanager.com/gtag/js?id=" + measurementId;
                            document.getElementsByTagName("head")[0].appendChild(script);
                        }
                        
                        ga4Projects[name] = measurementId;
                        const g4Config = { send_page_view: false, debug_mode: debug_mode }
                        if (user_id !== undefined) {
                            g4Config.user_id = user_id;
                        }
                        gtag('config', measurementId, g4Config);
                    } catch(e){
                        console.warn(e.message);
                    }
                });

                window.addEventListener("ga4_delete_project", ({ detail }) => {
                    try{
                        delete ga4Projects[detail.name];
                    } catch(e){
                        console.warn(e.message);
                    }
                });

                window.addEventListener("ga4_log_event", ({ detail }) => {
                    const ga4Ids = Object.values(ga4Projects);
                    if (ga4Ids.length > 0) {
                        gtag("event", detail.name, { send_to: ga4Ids, ...detail.data });
                    }
                });
            </script>
            <script>

                const projects = {};

                const isProjectValid = (config) => {
                    return config.projectId || config.measurementId;
                }

                const isFirebaseProject = (config) => {
                    return !!config.projectId;
                }

                //we need to send an event because analytics is loaded inside a script module 
                //so the methods aren't callable outside of it scope
               const addProject = (name, configJSON) => {
                    try{
                        const config = JSON.parse(configJSON);

                        if (!isProjectValid(config)) {
                            throw new Error("No valid configuration found!");
                        }

                        projects[name] = config;

                        const event = isFirebaseProject(config) ? "fa_add_project" :"ga4_add_project";
                        window.dispatchEvent(new CustomEvent(event, { detail: { name, config } }));
                    }catch(e){
                        console.warn(e.message);
                    }
                };

                const deleteProject = (name) => {
                    try{
                        const event = isFirebaseProject(projects[name]) ? "fa_delete_project" :"ga4_delete_project";
                        window.dispatchEvent(new CustomEvent(event, { detail: { name } }));
                    
                        delete projects[detail.name];
                    } catch(e){
                        console.warn(e.message);
                    }
                };

                const getEventParams = (name, dataJSON) => {
                    try{
                        const data = JSON.parse(dataJSON);
                        return { detail: { name, data } };
                    }catch(e){
                        console.warn(e.message);
                    }

                    return {};
                };

                const logFirebaseEvent = (name, dataJSON) => {
                    try{
                        const firebaseProjects = Object.values(projects).filter(function (project) {
                                                    return isFirebaseProject(project);
                                                });

                        if (firebaseProjects.length > 0) { 
                            window.dispatchEvent(new CustomEvent("fa_log_event", getEventParams(name, dataJSON)));
                        }
                    }catch(e){
                        console.warn(e.message);
                    }
                };

                const logGoogleAnalytics4Event = (name, dataJSON) => {
                    try{
                        const ga4Projects = Object.values(projects).filter(function (project) {
                                                return !isFirebaseProject(project);
                                            });

                        if (ga4Projects.length > 0) {
                            window.dispatchEvent(new CustomEvent("ga4_log_event", getEventParams(name, dataJSON)));
                        }
                    }catch(e){
                        console.warn(e.message);
                    }
                };

                const logScreenView = (dataJSON) => {
                    logFirebaseEvent("screen_view", dataJSON);
                };

                const logPageView = (dataJSON) => {
                    logGoogleAnalytics4Event("page_view", dataJSON);
                };

                const logEvent = (name, dataJSON) => {
                    logFirebaseEvent(name, dataJSON);
                    logGoogleAnalytics4Event(name, dataJSON);
                };

            </script>
        </body>
    </html>
`;
export { RAW_HTML };
//# sourceMappingURL=scripts.js.map